==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebDockManagerLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerLayoutDescription } from "./WebDockManagerLayoutDescription";
/**
 * @hidden
 */
var WebDockManagerLayoutDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerLayoutDescriptionMetadata, _super);
    function WebDockManagerLayoutDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerLayoutDescriptionMetadata.b = function (a) {
        if (WebDockManagerLayoutDescriptionMetadata.a == null) {
            WebDockManagerLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerLayoutDescriptionMetadata.c(WebDockManagerLayoutDescriptionMetadata.a);
        }
        if (a.g(WebDockManagerLayoutDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockManagerLayoutDescriptionMetadata.a);
        WebSplitPaneDescriptionMetadata.d(a);
    };
    WebDockManagerLayoutDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerLayout");
        a.item("RootPane", "ExportedType:WebSplitPane");
        a.item("FloatingPanes", "Collection:WebSplitPane:SplitPaneCollection:WebSplitPane");
    };
    WebDockManagerLayoutDescriptionMetadata.d = function (a) {
        WebDockManagerLayoutDescriptionMetadata.b(a);
        a.u("WebDockManagerLayout", function () { return new WebDockManagerLayoutDescription(); });
        a.t("WebDockManagerLayout", WebDockManagerLayoutDescriptionMetadata.a);
    };
    WebDockManagerLayoutDescriptionMetadata.$t = markType(WebDockManagerLayoutDescriptionMetadata, 'WebDockManagerLayoutDescriptionMetadata');
    WebDockManagerLayoutDescriptionMetadata.a = null;
    return WebDockManagerLayoutDescriptionMetadata;
}(Base));
export { WebDockManagerLayoutDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDockManagerLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerLayoutDescription } from "./WebDockManagerLayoutDescription";
/**
 * @hidden
 */
var WebDockManagerLayoutDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerLayoutDescriptionMetadata, _super);
    function WebDockManagerLayoutDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerLayoutDescriptionMetadata.b = function (a) {
        if (WebDockManagerLayoutDescriptionMetadata.a == null) {
            WebDockManagerLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerLayoutDescriptionMetadata.c(WebDockManagerLayoutDescriptionMetadata.a);
        }
        if (a.j(WebDockManagerLayoutDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockManagerLayoutDescriptionMetadata.a);
        WebSplitPaneDescriptionMetadata.d(a);
    };
    WebDockManagerLayoutDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerLayout");
        a.item("RootPane", "ExportedType:WebSplitPane");
        a.item("FloatingPanes", "Collection:WebSplitPane:SplitPaneCollection:WebSplitPane");
    };
    WebDockManagerLayoutDescriptionMetadata.d = function (a) {
        WebDockManagerLayoutDescriptionMetadata.b(a);
        a.aa("WebDockManagerLayout", function () { return new WebDockManagerLayoutDescription(); });
        a.z("WebDockManagerLayout", WebDockManagerLayoutDescriptionMetadata.a);
    };
    WebDockManagerLayoutDescriptionMetadata.$t = markType(WebDockManagerLayoutDescriptionMetadata, 'WebDockManagerLayoutDescriptionMetadata');
    WebDockManagerLayoutDescriptionMetadata.a = null;
    return WebDockManagerLayoutDescriptionMetadata;
}(Base));
export { WebDockManagerLayoutDescriptionMetadata };
